# AnaCore <img src="doc/img/logo/anacore_logo_40deg.png" alt="logo" width=60 rotate="60"/>


![license](https://img.shields.io/badge/license-GPLv3-blue)
![coverage](https://img.shields.io/badge/coverage-67%25-yellow)

## Description
Anapath Core is a package containing libraries for managing standard file
formats (BED, fasta, gff, gtf, MAF, newick, VCF, ...) and objects from NGS.

## Installation
### From PyPI
`pip install anacore`

### From sources
#### 1- Download sources
* [user way] Downloads the latest released release from `https://github.com/bialimed/anacore/releases`.
* [developper way] Clones the repository from the latest unreleased version: `git clone https://github.com/bialimed/AnaCore.git`.

#### 2- Install
`python setup.py install --user`

## Documentation
See `doc/index.html`

## Copyright
2017 Laboratoire d'Anatomo-Cytopathologie de l'Institut Universitaire du Cancer
Toulouse - Oncopole

## Contact
escudie.frederic@iuct-oncopole.fr
